public inbox for igt-dev@lists.freedesktop.org
 help / color / mirror / Atom feed
From: Ville Syrjala <ville.syrjala@linux.intel.com>
To: igt-dev@lists.freedesktop.org
Cc: Madhumitha Tolakanahalli Pradeep
	<madhumitha.tolakanahalli.pradeep@intel.com>,
	Manasi Navare <manasi.d.navare@intel.com>
Subject: [igt-dev] [PATCH i-g-t 1/5] tests/kms_tiled_display: Get rid of DP stuff
Date: Tue, 19 Oct 2021 23:19:36 +0300	[thread overview]
Message-ID: <20211019201940.31729-2-ville.syrjala@linux.intel.com> (raw)
In-Reply-To: <20211019201940.31729-1-ville.syrjala@linux.intel.com>

From: Ville Syrjälä <ville.syrjala@linux.intel.com>

There is nothing DP specific about the tile property. So
remove any mention of DP (and port sync which is an i915
hardware feature). Let's just talk about genlocked CRTCs
and tiled connectors, which is pretty generic.

Cc: Madhumitha Tolakanahalli Pradeep <madhumitha.tolakanahalli.pradeep@intel.com>
Cc: Manasi Navare <manasi.d.navare@intel.com>
Signed-off-by: Ville Syrjälä <ville.syrjala@linux.intel.com>
Reviewed-by: Manasi Navare <manasi.d.navare@intel.com>
---
 .../{kms_dp_tiled_display.c => kms_tiled_display.c} | 13 +++----------
 tests/meson.build                                   |  2 +-
 2 files changed, 4 insertions(+), 11 deletions(-)
 rename tests/{kms_dp_tiled_display.c => kms_tiled_display.c} (97%)

diff --git a/tests/meson.build b/tests/meson.build
index 0af3e03a3430..af2bda7e2cd5 100644
--- a/tests/meson.build
+++ b/tests/meson.build
@@ -27,7 +27,6 @@ test_progs = [
 	'kms_cursor_legacy',
 	'kms_dither',
 	'kms_dp_aux_dev',
-	'kms_dp_tiled_display',
 	'kms_flip',
 	'kms_flip_event_leak',
 	'kms_force_connector_basic',
@@ -54,6 +53,7 @@ test_progs = [
 	'kms_sequence',
 	'kms_setmode',
 	'kms_sysfs_edid_timing',
+	'kms_tiled_display',
 	'kms_tv_load_detect',
 	'kms_universal_plane',
 	'kms_vblank',
diff --git a/tests/kms_dp_tiled_display.c b/tests/kms_tiled_display.c
similarity index 97%
rename from tests/kms_dp_tiled_display.c
rename to tests/kms_tiled_display.c
index f030254dedbd..9eb980285b02 100644
--- a/tests/kms_dp_tiled_display.c
+++ b/tests/kms_tiled_display.c
@@ -25,7 +25,7 @@
  *      <madhumitha.tolakanahalli.pradeep@intel.com>
  *  Manasi Navare <manasi.d.navare@intel.com>
  *
  * Display Port Tiled Display Test
  * This test parses the tile information of the connectors that have TILE
  * property set, sets up the framebuffer with correct offsets corresponding to
  * the tile offsets and does an atomic modeset with two CRTCs for two
@@ -42,7 +42,7 @@
 #include "drm_fourcc.h"
 #include "igt_edid.h"
 
-IGT_TEST_DESCRIPTION("Test for Transcoder Port Sync for Display Port Tiled Displays");
+IGT_TEST_DESCRIPTION("Test for genlocked CRTCs with tiled displays");
 
 typedef struct {
 	igt_output_t *output;
@@ -121,8 +121,7 @@ static void get_number_of_h_tiles(data_t *data)
 						       res->connectors[i]);
 		igt_assert(connector);
 
-		if (connector->connection == DRM_MODE_CONNECTED &&
-		    connector->connector_type == DRM_MODE_CONNECTOR_DisplayPort) {
+		if (connector->connection == DRM_MODE_CONNECTED) {
 			get_connector_tile_props(data, connector, &tile);
 
 			data->num_h_tiles = tile.num_h_tile;
@@ -146,12 +145,6 @@ static void get_connectors(data_t *data)
 
 		igt_assert(conns[count].connector);
 
-		if (conns[count].connector->connector_type !=
-		    DRM_MODE_CONNECTOR_DisplayPort) {
-			drmModeFreeConnector(conns[count].connector);
-			continue;
-		}
-
 		get_connector_tile_props(data, conns[count].connector,
 					 &conns[count].tile);
 
@@ -25,7 +25,7 @@
  *  Manasi Navare <manasi.d.navare@intel.com>
  *
- * Display Port Tiled Display Test
+ * Tiled display genlocked CRTC test
  * This test parses the tile information of the connectors that have TILE
  * property set, sets up the framebuffer with correct offsets corresponding to
-- 
2.32.0

  reply	other threads:[~2021-10-19 20:19 UTC|newest]

Thread overview: 12+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-10-19 20:19 [igt-dev] [PATCH i-g-t 0/5] kms: Run tiled display tests on any set of connectors Ville Syrjala
2021-10-19 20:19 ` Ville Syrjala [this message]
2021-10-19 20:19 ` [igt-dev] [PATCH i-g-t 2/5] tests/kms_tiled_display: Replace the igt_display pointer with a struct Ville Syrjala
2021-10-19 22:07   ` [igt-dev] [PATCH i-g-t v2 " Ville Syrjala
2021-10-19 20:19 ` [igt-dev] [PATCH i-g-t 3/5] tests/kms_tiled_display: Limit the difference in the timestamps to one scanline Ville Syrjala
2021-10-19 20:19 ` [igt-dev] [PATCH i-g-t 4/5] lib/edid: Add support for making DisplayID tile blocks Ville Syrjala
2021-10-19 20:19 ` [igt-dev] [PATCH i-g-t 5/5] tests/kms_tiled_display: Override the EDID to fake some tiles Ville Syrjala
2021-10-19 20:48 ` [igt-dev] ✗ Fi.CI.BUILD: failure for kms: Run tiled display tests on any set of connectors Patchwork
2021-10-19 20:51 ` [igt-dev] ✗ GitLab.Pipeline: warning " Patchwork
2021-10-19 22:50 ` [igt-dev] ✓ Fi.CI.BAT: success for kms: Run tiled display tests on any set of connectors (rev2) Patchwork
2021-10-20  3:37 ` [igt-dev] ✓ Fi.CI.IGT: " Patchwork
  -- strict thread matches above, loose matches on Subject: below --
2020-03-13 16:11 [igt-dev] [PATCH i-g-t 1/5] tests/kms_tiled_display: Get rid of DP stuff Ville Syrjala

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20211019201940.31729-2-ville.syrjala@linux.intel.com \
    --to=ville.syrjala@linux.intel.com \
    --cc=igt-dev@lists.freedesktop.org \
    --cc=madhumitha.tolakanahalli.pradeep@intel.com \
    --cc=manasi.d.navare@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox